var __create = Object.create;
var __defProp = Object.defineProperty;
var __getOwnPropDesc = Object.getOwnPropertyDescriptor;
var __getOwnPropNames = Object.getOwnPropertyNames;
var __getProtoOf = Object.getPrototypeOf;
var __hasOwnProp = Object.prototype.hasOwnProperty;
var __export = (target, all) => {
  for (var name in all)
    __defProp(target, name, { get: all[name], enumerable: true });
};
var __copyProps = (to, from, except, desc) => {
  if (from && typeof from === "object" || typeof from === "function") {
    for (let key of __getOwnPropNames(from))
      if (!__hasOwnProp.call(to, key) && key !== except)
        __defProp(to, key, { get: () => from[key], enumerable: !(desc = __getOwnPropDesc(from, key)) || desc.enumerable });
  }
  return to;
};
var __toESM = (mod, isNodeMode, target) => (target = mod != null ? __create(__getProtoOf(mod)) : {}, __copyProps(
  // If the importer is in node compatibility mode or this is not an ESM
  // file that has been converted to a CommonJS file using a Babel-
  // compatible transform (i.e. "__esModule" has not been set), then set
  // "default" to the CommonJS "module.exports" for node compatibility.
  isNodeMode || !mod || !mod.__esModule ? __defProp(target, "default", { value: mod, enumerable: true }) : target,
  mod
));
var __toCommonJS = (mod) => __copyProps(__defProp({}, "__esModule", { value: true }), mod);

// src/index.ts
var src_exports = {};
__export(src_exports, {
  BitcoinUnit: () => BitcoinUnit,
  addUnit: () => addUnit,
  getUnit: () => getUnit,
  setDisplay: () => setDisplay
});
module.exports = __toCommonJS(src_exports);
var import_big2 = __toESM(require("big.js"));

// src/units.ts
var import_big = __toESM(require("big.js"));
var displayFormatDefaults = (display) => {
  var _a, _b, _c;
  return {
    format: (_a = display == null ? void 0 : display.format) != null ? _a : "",
    fractionDigits: (_b = display == null ? void 0 : display.fractionDigits) != null ? _b : 0,
    trailingZeros: (_c = display == null ? void 0 : display.trailingZeros) != null ? _c : false
  };
};
var Unit2 = class {
  constructor(name, value, display, aliases) {
    this.name = name;
    this.display = displayFormatDefaults(display);
    this.aliases = aliases ? aliases : [];
    if (value instanceof import_big.default) {
      this.value = value;
    } else {
      this.value = (0, import_big.default)(value);
    }
  }
  setDisplay(display) {
    this.display = display;
  }
};
var units = [
  new Unit2(
    "btc",
    1,
    {
      format: "{amount} BTC",
      fractionDigits: 8,
      trailingZeros: true
    },
    ["bitcoin"]
  ),
  new Unit2(
    "mbtc",
    1 / 1e3,
    {
      format: "{amount} mBTC",
      fractionDigits: 5,
      trailingZeros: true
    },
    ["millibtc"]
  ),
  new Unit2(
    "bit",
    1 / 1e6,
    {
      format: "{amount} \u03BCBTC",
      fractionDigits: 2,
      trailingZeros: true
    },
    ["microbtc"]
  ),
  new Unit2(
    "sats",
    1 / 1e8,
    {
      format: "{amount} satoshis",
      fractionDigits: 0,
      trailingZeros: false
    },
    ["sat", "satoshis", "satoshi"]
  )
];
var unitsMap;
var setUnitsMap = () => {
  unitsMap = /* @__PURE__ */ new Map();
  units.forEach((unit) => {
    unitsMap.set(unit.name, unit);
    unit.aliases.forEach((alias) => {
      unitsMap.set(alias, unit);
    });
  });
};
setUnitsMap();
var getUnit = (name) => {
  const unit = unitsMap.get(name.toLowerCase());
  if (!unit) {
    throw new Error(`Invalid unit: ${name}`);
  }
  return unit;
};
var addUnit = (name, value, display, aliases) => {
  const unit = new Unit2(name, value, display, aliases);
  units.push(unit);
  setUnitsMap();
};
var setDisplay = (unitName, display) => {
  const unit = getUnit(unitName);
  unit.display = displayFormatDefaults(display);
};

// src/index.ts
var BitcoinUnit = class _BitcoinUnit {
  constructor(value, unitName) {
    try {
      this.value = (0, import_big2.default)(value);
    } catch (error) {
      this.value = (0, import_big2.default)(0);
    }
    this.unit = getUnit(unitName);
  }
  to(toUnitName) {
    const toUnit = getUnit(toUnitName);
    this.value = this.value.times(this.unit.value).div(toUnit.value);
    this.unit = getUnit(toUnitName);
    return this;
  }
  getValue() {
    return this.value.toNumber();
  }
  getValueAsString() {
    return this.value.toFixed(this.unit.display.fractionDigits);
  }
  toString() {
    return this.getValueAsString();
  }
  format() {
    const { format, fractionDigits, trailingZeros } = this.unit.display;
    let valueString;
    const addThousandSeparator = (s) => s.replace(new RegExp("\\B(?<!\\.\\d*)(?=(\\d{3})+(?!\\d))", "g"), ",");
    const removeTrailingZeros = (s) => s.replace(/^(\d+\.\d*?[1-9])0+$/g, "$1");
    valueString = this.value.toFixed(fractionDigits, import_big2.default.roundDown);
    if (!trailingZeros) {
      valueString = removeTrailingZeros(valueString);
    }
    valueString = addThousandSeparator(valueString);
    return format.replace("{amount}", valueString);
  }
  static setDisplay(unitName, options) {
    setDisplay(unitName, options);
    return this;
  }
  static addUnit(name, value, display, aliases) {
    return addUnit(name, value, display, aliases);
  }
  static getUnit(name) {
    return getUnit(name);
  }
  static setFiat(currency, rate, display) {
    return _BitcoinUnit.addUnit(currency, 1 / rate, display);
  }
};
// Annotate the CommonJS export names for ESM import in node:
0 && (module.exports = {
  BitcoinUnit,
  addUnit,
  getUnit,
  setDisplay
});
//# sourceMappingURL=index.js.map