// src/index.ts
import Big2 from "big.js";

// src/units.ts
import Big from "big.js";
var displayFormatDefaults = (display) => {
  var _a, _b, _c;
  return {
    format: (_a = display == null ? void 0 : display.format) != null ? _a : "",
    fractionDigits: (_b = display == null ? void 0 : display.fractionDigits) != null ? _b : 0,
    trailingZeros: (_c = display == null ? void 0 : display.trailingZeros) != null ? _c : false
  };
};
var Unit2 = class {
  constructor(name, value, display, aliases) {
    this.name = name;
    this.display = displayFormatDefaults(display);
    this.aliases = aliases ? aliases : [];
    if (value instanceof Big) {
      this.value = value;
    } else {
      this.value = Big(value);
    }
  }
  setDisplay(display) {
    this.display = display;
  }
};
var units = [
  new Unit2(
    "btc",
    1,
    {
      format: "{amount} BTC",
      fractionDigits: 8,
      trailingZeros: true
    },
    ["bitcoin"]
  ),
  new Unit2(
    "mbtc",
    1 / 1e3,
    {
      format: "{amount} mBTC",
      fractionDigits: 5,
      trailingZeros: true
    },
    ["millibtc"]
  ),
  new Unit2(
    "bit",
    1 / 1e6,
    {
      format: "{amount} \u03BCBTC",
      fractionDigits: 2,
      trailingZeros: true
    },
    ["microbtc"]
  ),
  new Unit2(
    "sats",
    1 / 1e8,
    {
      format: "{amount} satoshis",
      fractionDigits: 0,
      trailingZeros: false
    },
    ["sat", "satoshis", "satoshi"]
  )
];
var unitsMap;
var setUnitsMap = () => {
  unitsMap = /* @__PURE__ */ new Map();
  units.forEach((unit) => {
    unitsMap.set(unit.name, unit);
    unit.aliases.forEach((alias) => {
      unitsMap.set(alias, unit);
    });
  });
};
setUnitsMap();
var getUnit = (name) => {
  const unit = unitsMap.get(name.toLowerCase());
  if (!unit) {
    throw new Error(`Invalid unit: ${name}`);
  }
  return unit;
};
var addUnit = (name, value, display, aliases) => {
  const unit = new Unit2(name, value, display, aliases);
  units.push(unit);
  setUnitsMap();
};
var setDisplay = (unitName, display) => {
  const unit = getUnit(unitName);
  unit.display = displayFormatDefaults(display);
};

// src/index.ts
var BitcoinUnit = class _BitcoinUnit {
  constructor(value, unitName) {
    try {
      this.value = Big2(value);
    } catch (error) {
      this.value = Big2(0);
    }
    this.unit = getUnit(unitName);
  }
  to(toUnitName) {
    const toUnit = getUnit(toUnitName);
    this.value = this.value.times(this.unit.value).div(toUnit.value);
    this.unit = getUnit(toUnitName);
    return this;
  }
  getValue() {
    return this.value.toNumber();
  }
  getValueAsString() {
    return this.value.toFixed(this.unit.display.fractionDigits);
  }
  toString() {
    return this.getValueAsString();
  }
  format() {
    const { format, fractionDigits, trailingZeros } = this.unit.display;
    let valueString;
    const addThousandSeparator = (s) => s.replace(new RegExp("\\B(?<!\\.\\d*)(?=(\\d{3})+(?!\\d))", "g"), ",");
    const removeTrailingZeros = (s) => s.replace(/^(\d+\.\d*?[1-9])0+$/g, "$1");
    valueString = this.value.toFixed(fractionDigits, Big2.roundDown);
    if (!trailingZeros) {
      valueString = removeTrailingZeros(valueString);
    }
    valueString = addThousandSeparator(valueString);
    return format.replace("{amount}", valueString);
  }
  static setDisplay(unitName, options) {
    setDisplay(unitName, options);
    return this;
  }
  static addUnit(name, value, display, aliases) {
    return addUnit(name, value, display, aliases);
  }
  static getUnit(name) {
    return getUnit(name);
  }
  static setFiat(currency, rate, display) {
    return _BitcoinUnit.addUnit(currency, 1 / rate, display);
  }
};
export {
  BitcoinUnit,
  addUnit,
  getUnit,
  setDisplay
};
//# sourceMappingURL=index.mjs.map