// src/units.ts
import Big from "big.js";
var displayFormatDefaults = (display) => {
  var _a, _b, _c;
  return {
    format: (_a = display == null ? void 0 : display.format) != null ? _a : "",
    fractionDigits: (_b = display == null ? void 0 : display.fractionDigits) != null ? _b : 0,
    trailingZeros: (_c = display == null ? void 0 : display.trailingZeros) != null ? _c : false
  };
};
var Unit = class {
  constructor(name, value, display, aliases) {
    this.name = name;
    this.display = displayFormatDefaults(display);
    this.aliases = aliases ? aliases : [];
    if (value instanceof Big) {
      this.value = value;
    } else {
      this.value = Big(value);
    }
  }
  setDisplay(display) {
    this.display = display;
  }
};
var units = [
  new Unit(
    "btc",
    1,
    {
      format: "{amount} BTC",
      fractionDigits: 8,
      trailingZeros: true
    },
    ["bitcoin"]
  ),
  new Unit(
    "mbtc",
    1 / 1e3,
    {
      format: "{amount} mBTC",
      fractionDigits: 5,
      trailingZeros: true
    },
    ["millibtc"]
  ),
  new Unit(
    "bit",
    1 / 1e6,
    {
      format: "{amount} \u03BCBTC",
      fractionDigits: 2,
      trailingZeros: true
    },
    ["microbtc"]
  ),
  new Unit(
    "sats",
    1 / 1e8,
    {
      format: "{amount} satoshis",
      fractionDigits: 0,
      trailingZeros: false
    },
    ["sat", "satoshis", "satoshi"]
  )
];
var unitsMap;
var setUnitsMap = () => {
  unitsMap = /* @__PURE__ */ new Map();
  units.forEach((unit) => {
    unitsMap.set(unit.name, unit);
    unit.aliases.forEach((alias) => {
      unitsMap.set(alias, unit);
    });
  });
};
setUnitsMap();
var getUnit = (name) => {
  const unit = unitsMap.get(name.toLowerCase());
  if (!unit) {
    throw new Error(`Invalid unit: ${name}`);
  }
  return unit;
};
var addUnit = (name, value, display, aliases) => {
  const unit = new Unit(name, value, display, aliases);
  units.push(unit);
  setUnitsMap();
};
var setDisplay = (unitName, display) => {
  const unit = getUnit(unitName);
  unit.display = displayFormatDefaults(display);
};
export {
  Unit,
  addUnit,
  getUnit,
  setDisplay
};
//# sourceMappingURL=units.mjs.map